@@ -257,7 +257,7 @@ def list_monitors_info(method: Optional[str] = None, allow_duplicates: bool = Fa
     Args:
         method (str): the method to use to list the available monitors.
             On Windows this can be `'wmi'` or `'vcp'`.
-            On Linux this can be `'light'`, `'xrandr'`, `'ddcutil'` or `'xbacklight'`.
+            On Linux this can be `'light'`, `'xrandr'`, `'ddcutil'` or `'sysfiles'`.
         allow_duplicates (bool): whether to filter out duplicate displays or not
 
     Returns:
@@ -301,7 +301,7 @@ def list_monitors(method: Optional[str] = None) -> List[str]:
     Args:
         method (str): the method to use to list the available monitors.
             On Windows this can be `'wmi'` or `'vcp'`.
-            On Linux this can be `'light'`, `'xrandr'`, `'ddcutil'` or `'xbacklight'`.
+            On Linux this can be `'light'`, `'xrandr'`, `'ddcutil'` or `'sysfiles'`.
 
     Returns:
         list: list of strings
@@ -403,6 +403,38 @@ class EDID:
                 pass
         return name, serial.strip(' ')
 
+    @staticmethod
+    def hexdump(file: str) -> str:
+        '''
+        Returns a hexadecimal string of binary data from a file
+
+        Args:
+            file (str): the file to read
+
+        Returns:
+            str: one long hex string
+
+        Example:
+            ```python
+            from screen_brightness_control import EDID
+
+            print(EDID.hexdump('/sys/class/backlight/intel_backlight/device/edid'))
+            # '00ffffffffffff00...'
+            ```
+        '''
+        with open(file, 'rb') as f:
+            data = f.read()
+
+        hex_str = ''
+        for char in data:
+            if char < 16:
+                # hex values less than 16 get represented as single char
+                # eg: 15 -> 'f' instead of '0f'
+                hex_str += '0'
+            hex_str += f'{char:x}'  # represent binary as hex string
+
+        return hex_str
+
 
 MONITOR_MANUFACTURER_CODES = {
     "AAC": "AcerView",
@@ -1020,5 +1052,5 @@ else:
     raise NotImplementedError(f'{plat} is not yet supported')
 del(plat)
 
-__version__ = '0.10.0'
+__version__ = '0.11.0'
 __author__ = 'Crozzers'
