@@ -2,7 +2,179 @@ import subprocess
 import os
 from . import _monitor_brand_lookup, filter_monitors, __cache__, EDID
 from typing import List, Union, Optional
-from warnings import warn
+
+
+class SysFiles:
+    '''
+    A way of getting display information and adjusting the brightness
+    that does not rely on any 3rd party software.
+
+    This class works with displays that show up in the `/sys/class/backlight`
+    directory (so usually laptop displays).
+
+    To set the brightness, your user will need write permissions for
+    `/sys/class/backlight/*/brightness` or you will need to run the program
+    as root.
+    '''
+    @classmethod
+    def get_display_info(cls, display: Optional[Union[int, str]] = None) -> List[dict]:
+        '''
+        Returns information about detected displays by reading files from the
+        `/sys/class/backlight` directory
+
+        Args:
+            display (str or int): [*Optional*] The monitor to return info about.
+                Pass in the serial number, name, model, interface, edid or index.
+                This is passed to `filter_monitors`
+
+        Returns:
+            list: list of dicts
+
+        Example:
+            ```python
+            import screen_brightness_control as sbc
+
+            # get info about all monitors
+            info = sbc.linux.SysFiles.get_display_info()
+            # EG output: [{'name': 'edp-backlight', 'path': '/sys/class/backlight/edp-backlight', edid': '00ffff...'}]
+
+            # get info about the primary monitor
+            primary_info = sbc.linux.SysFiles.get_display_info(0)[0]
+
+            # get info about a monitor called 'edp-backlight'
+            edp_info = sbc.linux.SysFiles.get_display_info('edp-backlight')[0]
+            ```
+        '''
+        displays = {}
+        index = 0
+        for folder in os.listdir('/sys/class/backlight'):
+            if os.path.isfile(f'/sys/class/backlight/{folder}/device/edid'):
+                device = {
+                    'name': folder,
+                    'path': f'/sys/class/backlight/{folder}',
+                    'method': cls,
+                    'index': index,
+                    'model': None,
+                    'serial': None,
+                    'manufacturer': None,
+                    'manufacturer_id': None,
+                    'edid': EDID.hexdump(f'/sys/class/backlight/{folder}/device/edid'),
+                    'scale': None
+                }
+
+                try:
+                    # try to get resolution of brightness settings
+                    with open(os.path.join(device['path'], 'max_brightness'), 'r') as f:
+                        device['scale'] = int(f.read().rstrip('\n')) / 100
+                except (FileNotFoundError, TypeError):
+                    # if the scale cannot be figured out then exclude the display
+                    continue
+
+                # now check for duplicate displays
+                if device['edid'] in displays:
+                    if (
+                        displays[device['edid']]['scale'] == 1
+                        or displays[device['edid']]['scale'] >= device['scale']
+                    ):
+                        # if there is a duplicate display, pick the display with
+                        # a scale equal to 1 or the display with the highest scale.
+                        # Reduces rounding errrors when converting percentages
+                        # to 'actual' values
+                        continue
+
+                name, serial = EDID.parse_edid(device['edid'])
+                if name is not None:
+                    device['name'], device['serial'] = name, serial
+
+                    try:
+                        manufacturer_id, manufacturer = _monitor_brand_lookup(name.split(' ')[0])
+                    except TypeError:
+                        device['manufacturer'] = name.split(' ')[0]
+                        device['manufacturer_id'] = None
+                    else:
+                        device['manufacturer_id'], device['manufacturer'] = manufacturer_id, manufacturer
+
+                    device['model'] = name.split(' ')[1]
+
+                displays[device['edid']] = device
+                index += 1
+
+        displays = list(displays.values())
+        if display is not None:
+            displays = filter_monitors(display=display, haystack=displays, include=['path'])
+        return displays
+
+    @classmethod
+    def get_brightness(cls, display: Optional[int] = None) -> List[int]:
+        '''
+        Gets the brightness for a display by reading the brightness files
+        stored in `/sys/class/backlight/*/brightness`
+
+        Args:
+            display (int): The specific display you wish to query.
+
+        Returns:
+            list: list of ints (0 to 100)
+
+        Example:
+            ```python
+            import screen_brightness_control as sbc
+
+            # get the current display brightness
+            current_brightness = sbc.linux.SysFiles.get_brightness()
+
+            # get the brightness of the primary display
+            primary_brightness = sbc.linux.SysFiles.get_brightness(display = 0)[0]
+
+            # get the brightness of the secondary display
+            edp_brightness = sbc.linux.SysFiles.get_brightness(display = 1)[0]
+            ```
+        '''
+        info = cls.get_display_info()
+        if display is not None:
+            info = [info[display]]
+
+        results = []
+        for device in info:
+            with open(os.path.join(device['path'], 'brightness'), 'r') as f:
+                brightness = int(f.read().rstrip('\n'))
+            results.append(int(brightness / device['scale']))
+
+        return results
+
+    @classmethod
+    def set_brightness(cls, value: int, display: Optional[int] = None):
+        '''
+        Sets the brightness for a display by writing to the brightness files
+        stored in `/sys/class/backlight/*/brightness`.
+        This function requires permission to write to these files which is
+        usually provided when it's run as root.
+
+        Args:
+            value (int): Sets the brightness to this value
+            display (int): The specific display you wish to query.
+
+        Example:
+            ```python
+            import screen_brightness_control as sbc
+
+            # set the brightness to 50%
+            sbc.linux.SysFiles.set_brightness(50)
+
+            # set the primary display brightness to 75%
+            sbc.linux.SysFiles.set_brightness(75, display = 0)
+
+            # set the secondary display brightness to 25%
+            sbc.linux.SysFiles.set_brightness(75, display = 1)
+            ```
+        '''
+        info = cls.get_display_info()
+        if display is not None:
+            info = [info[display]]
+
+        for device in info:
+            with open(os.path.join(device['path'], 'brightness'), 'w') as f:
+                f.write(str(int(value * device['scale'])))
 
 
 class Light:
@@ -14,7 +186,10 @@ class Light:
     @classmethod
     def get_display_info(cls, display: Optional[Union[int, str]] = None) -> List[dict]:
         '''
-        Returns information about detected displays as reported by Light
+        Returns information about detected displays as reported by Light.
+
+        It works by taking the output of `SysFiles.get_display_info` and
+        filtering out any displays that aren't supported by Light
 
         Args:
             display (str or int): [*Optional*] The monitor to return info about.
@@ -39,52 +214,20 @@ class Light:
             edp_info = sbc.linux.Light.get_display_info('edp-backlight')[0]
             ```
         '''
-        res = subprocess.run([cls.executable, '-L'], stdout=subprocess.PIPE).stdout.decode().split('\n')
+        light_output = subprocess.check_output([cls.executable, '-L']).decode()
         displays = []
-        count = 0
-        for r in res:
-            if 'backlight' in r and 'sysfs/backlight/auto' not in r:
-                r = r[r.index('backlight/') + 10:]
-                if os.path.isfile(f'/sys/class/backlight/{r}/device/edid'):
-                    tmp = {
-                        'name': r,
-                        'path': f'/sys/class/backlight/{r}',
-                        'light_path': f'sysfs/backlight/{r}',
-                        'method': cls,
-                        'index': count,
-                        'model': None,
-                        'serial': None,
-                        'manufacturer': None,
-                        'manufacturer_id': None,
-                        'edid': None
-                    }
-                    count += 1
-                    try:
-                        out = subprocess.check_output(
-                            ['hexdump', tmp['path'] + '/device/edid'],
-                            stderr=subprocess.DEVNULL
-                        ).decode().split('\n')
-                        # either the hexdump reports each hex char backwards (ff00 instead of 00ff)
-                        # or both xrandr and ddcutil do. So I swap these bits around
-                        edid = ''
-                        for line in out:
-                            for i in line.split(' '):
-                                if len(i) == 4:
-                                    edid += i[2:] + i[:2]
-                        tmp['edid'] = edid
-                        name, serial = EDID.parse_edid(edid)
-                        if name is not None:
-                            tmp['serial'] = serial
-                            tmp['name'] = name
-                        try:
-                            tmp['manufacturer_id'], tmp['manufacturer'] = _monitor_brand_lookup(name.split(' ')[0])
-                        except Exception:
-                            tmp['manufacturer'] = name.split(' ')[0]
-                            tmp['manufacturer_id'] = None
-                        tmp['model'] = name.split(' ')[1]
-                    except Exception:
-                        pass
-                    displays.append(tmp)
+        index = 0
+        for device in SysFiles.get_display_info():
+            # SysFiles scrapes info from the same place that Light used to
+            # so it makes sense to use that output
+            if device['path'].replace('/sys/class', 'sysfs') in light_output:
+                del device['scale']
+                device['light_path'] = device['path'].replace('/sys/class', 'sysfs')
+                device['method'] = cls
+                device['index'] = index
+
+                displays.append(device)
+                index += 1
 
         if display is not None:
             displays = filter_monitors(display=display, haystack=displays, include=['path', 'light_path'])
@@ -123,7 +266,7 @@ class Light:
     @classmethod
     def get_brightness(cls, display: Optional[int] = None) -> List[int]:
         '''
-        Sets the brightness for a display using the light executable
+        Gets the brightness for a display using the light executable
 
         Args:
             display (int): The specific display you wish to query.
@@ -541,7 +684,7 @@ class DDCUtil:
 
         res = []
         for m in monitors:
-            out = __cache__.get('ddcutil_' + m['edid'] + '_brightness')
+            out = __cache__.get(f'ddcutil_brightness_{m["index"]}')
             if out is None:
                 out = subprocess.check_output(
                     [
@@ -551,7 +694,7 @@ class DDCUtil:
                         f'--sleep-multiplier={cls.sleep_multiplier}'
                     ]
                 ).decode().split(' ')[-2]
-                __cache__.store('ddcutil_' + m['edid'] + '_brightness', out, expires=0.5)
+                __cache__.store(f'ddcutil_brightness_{m["index"]}', out, expires=0.5)
             try:
                 res.append(int(out))
             except Exception:
@@ -632,11 +775,14 @@ def list_monitors_info(method: Optional[str] = None, allow_duplicates: bool = Fa
     '''
     info = __cache__.get('linux_monitors_info', method=method, allow_duplicates=allow_duplicates)
     if info is None:
-        methods = [XRandr, DDCUtil, Light]
+        methods = [XRandr, DDCUtil, Light, SysFiles]
         if method is not None:
             method = method.lower()
-            if method not in ('xrandr', 'ddcutil', 'light'):
-                raise ValueError('method must be \'xrandr\' or \'ddcutil\' or \'light\' to get monitor information')
+            if method not in ('xrandr', 'ddcutil', 'light', 'sysfiles'):
+                raise ValueError((
+                    'method must be "xrandr" or "ddcutil" or "light"'
+                    ' or "sysfiles" to get monitor information'
+                ))
 
         info = []
         edids = []
@@ -654,65 +800,3 @@ def list_monitors_info(method: Optional[str] = None, allow_duplicates: bool = Fa
                             info.append(i)
         __cache__.store('linux_monitors_info', info, method=method, allow_duplicates=allow_duplicates)
     return info
-
-
-def get_brightness_from_sysfiles(display: int = None) -> int:
-    '''
-    **DEPRECATED**.
-    Returns the current display brightness by reading files from `/sys/class/backlight`
-
-    Args:
-        display (int): The index of the display you wish to query
-
-    Returns:
-        int: from 0 to 100
-
-    Raises:
-        Exception: if no values could be obtained from reading `/sys/class/backlight`
-        FileNotFoundError: if the `/sys/class/backlight` directory doesn't exist or it is empty
-
-    Example:
-        ```python
-        import screen_brightness_control as sbc
-
-        brightness = sbc.linux.get_brightness_from_sysfiles()
-        # Eg Output: 100
-        ```
-    '''
-    warn(
-        (
-            'screen_brightness_control.linux.get_brightness_from_sysfiles is'
-            ' deprecated and will be removed in the next update'
-        ), DeprecationWarning
-    )
-    backlight_dir = '/sys/class/backlight/'
-    error = []
-    # if function has not returned yet try reading the brightness file
-    if os.path.isdir(backlight_dir) and os.listdir(backlight_dir) != []:
-        # if the backlight dir exists and is not empty
-        folders = [dir for dir in os.listdir(backlight_dir) if os.path.isdir(os.path.join(backlight_dir, dir))]
-        if display is not None:
-            folders = [folders[display]]
-        for folder in folders:
-            try:
-                # try to read the brightness value in the file
-                with open(os.path.join(backlight_dir, folder, 'brightness'), 'r') as f:
-                    brightness_value = int(float(str(f.read().rstrip('\n'))))
-
-                try:
-                    # try open the max_brightness file to calculate the value to set the brightness file to
-                    with open(os.path.join(backlight_dir, folder, 'max_brightness'), 'r') as f:
-                        max_brightness = int(float(str(f.read().rstrip('\n'))))
-                except Exception:
-                    # if the file does not exist we cannot calculate the brightness
-                    return False
-                brightness_value = int(round((brightness_value / max_brightness) * 100, 0))
-                return brightness_value
-            except Exception as e:
-                error.append([type(Exception).__name__, e])
-        # if function hasn't returned, it failed
-        exc = f'Failed to get brightness from {backlight_dir}:'
-        for e in error:
-            exc += f'\n    {e[0]}: {e[1]}'
-        raise Exception(exc)
-    raise FileNotFoundError(f'Backlight directory {backlight_dir} not found')
